summaryrefslogtreecommitdiff
path: root/layouts/resize.sh
diff options
context:
space:
mode:
authorspiderr <spider@viovio.com>2010-08-06 13:43:27 -0400
committerspiderr <spider@viovio.com>2010-08-06 13:43:27 -0400
commit2a9554c8d225fc0ddb30fe289fe8ada7f4b8c659 (patch)
tree62f09d0512aa59e5e57aec2eb580bd1d16eca62a /layouts/resize.sh
parent8b08bb12dc30a78c7654080cf3a7fb9e41c5629b (diff)
downloadthemes-2a9554c8d225fc0ddb30fe289fe8ada7f4b8c659.tar.gz
themes-2a9554c8d225fc0ddb30fe289fe8ada7f4b8c659.tar.bz2
themes-2a9554c8d225fc0ddb30fe289fe8ada7f4b8c659.zip
major refinement of gala layouts - layouts are still the same, however #content was removed from all positioning and #wrapper was used for main content, so now you can pad up #content like you can side columns. update all fixed sizes to use 960px multiples to conform to blueprintcss styling.
Diffstat (limited to 'layouts/resize.sh')
-rwxr-xr-xlayouts/resize.sh22
1 files changed, 11 insertions, 11 deletions
diff --git a/layouts/resize.sh b/layouts/resize.sh
index 075223f..c29a649 100755
--- a/layouts/resize.sh
+++ b/layouts/resize.sh
@@ -1,7 +1,7 @@
#!/bin/bash
echo "This script will resize statically sized layouts to whatever size you want. If
you have not modified the script manually, it will resize pixel values to work
-with a total width of 900px instead of the original 700px. If this is not what
+with a total width of 960px instead of the original 700px. If this is not what
you want, please edit this file manually to suit your needs."
echo
@@ -32,30 +32,30 @@ echo 1; sleep 1
echo
echo "Executing substitutions."
# This sample script will resize all statically set dimensions to work with 900px instead of 800px
# total width
-find . -name "*.css" -exec perl -i -wpe 's/700px/900px/g' {} \;
+find . -name "*.css" -exec perl -i -wpe 's/900px/960px/g' {} \;
# half the total width
-find . -name "*.css" -exec perl -i -wpe 's/350px/450px/g' {} \;
+find . -name "*.css" -exec perl -i -wpe 's/450px/480px/g' {} \;
# one side column
-find . -name "*.css" -exec perl -i -wpe 's/200px/260px/g' {} \;
+find . -name "*.css" -exec perl -i -wpe 's/260px/240px/g' {} \;
# two side columns
-find . -name "*.css" -exec perl -i -wpe 's/400px/520px/g' {} \;
+find . -name "*.css" -exec perl -i -wpe 's/520px/480px/g' {} \;
# remainder of total width - one side column
-find . -name "*.css" -exec perl -i -wpe 's/500px/640px/g' {} \;
+find . -name "*.css" -exec perl -i -wpe 's/540px/720px/g' {} \;
# narrow side column (used when there are 2 side columns in a static layout)
-find . -name "*.css" -exec perl -i -wpe 's/150px/220px/g' {} \;
+find . -name "*.css" -exec perl -i -wpe 's/220px/200px/g' {} \;
# two narrow side columns
-find . -name "*.css" -exec perl -i -wpe 's/300px/440px/g' {} \;
+find . -name "*.css" -exec perl -i -wpe 's/440px/400px/g' {} \;
# remainder of total width - one narrow side column
-find . -name "*.css" -exec perl -i -wpe 's/550px/680px/g' {} \;
+find . -name "*.css" -exec perl -i -wpe 's/680px/560px/g' {} \;
## Use the replacements below to generate a very small layout that works with the layout_style.tar.gz
## This sample script will resize all statically set dimensions to work with 900px instead of 800px
## total width
#find . -name "*.css" -exec perl -i -wpe 's/700px/100px/g' {} \;
## half the total width
@@ -32,30 +32,30 @@ echo 1; sleep 1
echo
echo "Executing substitutions."
-# This sample script will resize all statically set dimensions to work with 900px instead of 800px
+# This sample script will resize all statically set dimensions to work with 960px instead of 800px
# total width
@@ -32,30 +32,30 @@ echo 1; sleep 1
## Use the replacements below to generate a very small layout that works with the layout_style.tar.gz
-## This sample script will resize all statically set dimensions to work with 900px instead of 800px
+## This sample script will resize all statically set dimensions to work with 960px instead of 800px
## total width
#find . -name "*.css" -exec perl -i -wpe 's/700px/100px/g' {} \;